"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthDataSource = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const authentication_service_1 = require("@sourceloop/authentication-service");
const DEFAULT_MAX_CONNECTIONS = 25;
const DEFAULT_DB_IDLE_TIMEOUT_MILLIS = 60000;
const DEFAULT_DB_CONNECTION_TIMEOUT_MILLIS = 2000;
const config = {
    name: 'auth',
    connector: 'postgresql',
    host: process.env.DB_HOST,
    port: process.env.DB_PORT,
    user: process.env.DB_USER,
    schema: process.env.DB_SCHEMA,
    password: process.env.DB_PASSWORD,
    database: process.env.DB_DATABASE,
};
// Observe application's life cycle to disconnect the datasource when
// application is stopped. This allows the application to be shut down
// gracefully. The `stop()` method is inherited from `juggler.DataSource`.
// Learn more at https://loopback.io/doc/en/lb4/Life-cycle.html
let AuthDataSource = exports.AuthDataSource = class AuthDataSource extends repository_1.juggler.DataSource {
    constructor(dsConfig = config) {
        var _a, _b, _c, _d;
        if (!!+((_a = process.env.ENABLE_DB_CONNECTION_POOLING) !== null && _a !== void 0 ? _a : 0)) {
            const dbPool = {
                max: +((_b = process.env.DB_MAX_CONNECTIONS) !== null && _b !== void 0 ? _b : DEFAULT_MAX_CONNECTIONS),
                idleTimeoutMillis: +((_c = process.env.DB_IDLE_TIMEOUT_MILLIS) !== null && _c !== void 0 ? _c : DEFAULT_DB_IDLE_TIMEOUT_MILLIS),
                connectionTimeoutMillis: +((_d = process.env.DB_CONNECTION_TIMEOUT_MILLIS) !== null && _d !== void 0 ? _d : DEFAULT_DB_CONNECTION_TIMEOUT_MILLIS),
            };
            dsConfig = { ...dsConfig, ...dbPool };
        }
        super(dsConfig);
    }
};
AuthDataSource.dataSourceName = authentication_service_1.AuthDbSourceName;
AuthDataSource.defaultConfig = config;
exports.AuthDataSource = AuthDataSource = tslib_1.__decorate([
    (0, core_1.lifeCycleObserver)('datasource'),
    tslib_1.__param(0, (0, core_1.inject)('datasources.config.auth', { optional: true })),
    tslib_1.__metadata("design:paramtypes", [Object])
], AuthDataSource);
//# sourceMappingURL=auth.datasource.js.map